summaryrefslogtreecommitdiffstats
path: root/test/t/test_grep.py
diff options
context:
space:
mode:
authorDaniel Baumann <daniel.baumann@progress-linux.org>2024-05-04 01:03:18 +0000
committerDaniel Baumann <daniel.baumann@progress-linux.org>2024-05-04 01:03:18 +0000
commitf4acb49ea148cdd899f7f29f1591c7bc853c2135 (patch)
treeb62d60873864065d6428a84a119dd8a3c90f1397 /test/t/test_grep.py
parentAdding upstream version 1:2.11. (diff)
downloadbash-completion-f4acb49ea148cdd899f7f29f1591c7bc853c2135.tar.xz
bash-completion-f4acb49ea148cdd899f7f29f1591c7bc853c2135.zip
Adding upstream version 1:2.12.0.upstream/1%2.12.0
Signed-off-by: Daniel Baumann <daniel.baumann@progress-linux.org>
Diffstat (limited to 'test/t/test_grep.py')
-rw-r--r--test/t/test_grep.py12
1 files changed, 11 insertions, 1 deletions
diff --git a/test/t/test_grep.py b/test/t/test_grep.py
index a249122..ded7fb5 100644
--- a/test/t/test_grep.py
+++ b/test/t/test_grep.py
@@ -11,6 +11,16 @@ class TestGrep:
"""
Test --no-*dir isn't restricted to dirs only.
Not really a grep option, but tests _longopt.
"""
assert completion == "foo foo.d/".split()
+
+ @pytest.mark.complete("grep TZ ", cwd="shared/default")
+ def test_no_variable_assignment_confusion(self, completion):
+ """
+ Test TZ doesn't trigger known variable value assignment completion.
+
+ Not really a grep specific, but good to test somewhere.
+ Refs https://github.com/scop/bash-completion/issues/457
+ """
+ assert "foo" in completion
@@ -11,6 +11,16 @@ class TestGrep:
"""
Test --no-*dir isn't restricted to dirs only.
- Not really a grep option, but tests _longopt.
+ Not really a grep option, but tests _comp_complete_longopt.
"""
assert completion == "foo foo.d/".split()